==> tdeedu-trinity-14.1.2.tar.xz: tdeedu-trinity-14.1.2/kverbos/kverbos/kverbosoptions.cpp <==
/***************************************************************************
                          kverbosoptions.cpp  -  description
                             -------------------
    begin                : Sat Dec 15 2001
    copyright            : (C) 2001 by Arnold Kraschinski
    email                : arnold.k67@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "tqlabel.h"
#include "tqcheckbox.h"
#include "kverbosoptions.h"

KVerbosOptions::KVerbosOptions( TQWidget* parent /*= 0*/, const char* name /*= 0*/, bool modal /*= FALSE*/, WFlags fl /*= 0*/ )
: QVerbosOptions(parent, name, modal, fl)
{
	// some times are disabled because they aren't ready yet.
	LabelSubPasado->setEnabled(false);
	LabelSubPresente->setEnabled(false);
	LabelSubFuturo->setEnabled(false);
	LabelImperativo->setEnabled(false);
	CheckBox1_6->setEnabled(false);
	CheckBox2_6->setEnabled(false);
	CheckBox3_6->setEnabled(false);
	CheckBox1_7->setEnabled(false);
	CheckBox2_7->setEnabled(false);
	CheckBox3_7->setEnabled(false);	
	CheckBox1_8->setEnabled(false);
	CheckBox2_8->setEnabled(false);
	CheckBox3_8->setEnabled(false);	
	CheckBox1_9->setEnabled(false);		
}

KVerbosOptions::~KVerbosOptions()
{
}



// Wird durch den OK-Button aufgerufen und beendet den Dialog. nderungen
// werden bernommen.
void KVerbosOptions::slotDlgEnde()
{
  done(1);
}

// Wird durch den Cancel-Button aufgerufen und beendet den Dialog ohne
// nderungen zu bernehmen.
void KVerbosOptions::slotCancel()
{
  done(0);
}

==> tdeedu-trinity_14.2.0~pre138.orig.tar.xz: tdeedu-trinity-14.2.0~pre138+08a7b20b/kverbos/kverbos/kverbosoptions.cpp <==
/***************************************************************************
                          kverbosoptions.cpp  -  description
                             -------------------
    begin                : Sat Dec 15 2001
    copyright            : (C) 2001 by Arnold Kraschinski
    email                : arnold.k67@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "tqlabel.h"
#include "tqcheckbox.h"
#include "kverbosoptions.h"

KVerbosOptions::KVerbosOptions( TQWidget* parent /*= 0*/, const char* name /*= 0*/, bool modal /*= false*/, WFlags fl /*= 0*/ )
: QVerbosOptions(parent, name, modal, fl)
{
	// some times are disabled because they aren't ready yet.
	LabelSubPasado->setEnabled(false);
	LabelSubPresente->setEnabled(false);
	LabelSubFuturo->setEnabled(false);
	LabelImperativo->setEnabled(false);
	CheckBox1_6->setEnabled(false);
	CheckBox2_6->setEnabled(false);
	CheckBox3_6->setEnabled(false);
	CheckBox1_7->setEnabled(false);
	CheckBox2_7->setEnabled(false);
	CheckBox3_7->setEnabled(false);	
	CheckBox1_8->setEnabled(false);
	CheckBox2_8->setEnabled(false);
	CheckBox3_8->setEnabled(false);	
	CheckBox1_9->setEnabled(false);		
}

KVerbosOptions::~KVerbosOptions()
{
}



// Wird durch den OK-Button aufgerufen und beendet den Dialog. nderungen
// werden bernommen.
void KVerbosOptions::slotDlgEnde()
{
  done(1);
}

// Wird durch den Cancel-Button aufgerufen und beendet den Dialog ohne
// nderungen zu bernehmen.
void KVerbosOptions::slotCancel()
{
  done(0);
}
